GaugeThemeExtension class
Flutter ThemeExtension that supplies GaugeStyle and defaultMode to any widget in the subtree.
- Inheritance
-
- Object
- ThemeExtension<
GaugeThemeExtension> - GaugeThemeExtension
Constructors
- GaugeThemeExtension({required GaugeStyle style, GaugeMode defaultMode = GaugeMode.ambient})
-
const
Properties
- defaultMode → GaugeMode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → GaugeStyle
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{GaugeStyle? style, GaugeMode? defaultMode}) → GaugeThemeExtension -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant GaugeThemeExtension? other, double t) → GaugeThemeExtension -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited