ThermometerGauge class

A classic thermometer gauge. controller.value is in Celsius.

Inheritance

Constructors

ThermometerGauge({Key? key, required GaugeController controller, double minCelsius = -20, double maxCelsius = 50, TemperatureScale scale = TemperatureScale.celsius, bool showScale = true, GaugeStyle? style, GaugeMode? mode, String? semanticsLabel})
const
ThermometerGauge.bodyTemp({Key? key, required GaugeController controller, TemperatureScale scale = TemperatureScale.celsius, GaugeStyle? style, GaugeMode? mode})
Body temperature preset (35–42°C).
factory
ThermometerGauge.oven({Key? key, required GaugeController controller, GaugeStyle? style, GaugeMode? mode})
Oven / industrial temperature preset.
factory

Properties

controller GaugeController
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxCelsius double
final
minCelsius double
final
mode GaugeMode?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale TemperatureScale
final
semanticsLabel String?
final
showScale bool
final
style GaugeStyle?
final

Methods

createElement() LeafRenderObjectElement
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
createRenderObject(BuildContext context) ThermometerGaugeRenderBox
Creates an instance of the RenderObject class that this RenderObjectWidget represents, using the configuration described by this RenderObjectWidget.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didUnmountRenderObject(covariant RenderObject renderObject) → void
This method is called when a RenderObject that was previously associated with this widget is removed from the render tree. The provided RenderObject will be of the same type as the one created by this widget's createRenderObject method.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateRenderObject(BuildContext context, covariant ThermometerGaugeRenderBox renderObject) → void
Copies the configuration described by this RenderObjectWidget to the given RenderObject, which will be of the same type as returned by this object's createRenderObject.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited