minTileWidth property
The narrowest a grid tile is allowed to get before another column is dropped. Smaller values pack more columns into the same width.
Implementation
final double minTileWidth;
The narrowest a grid tile is allowed to get before another column is dropped. Smaller values pack more columns into the same width.
final double minTileWidth;