GaugeStyle class abstract
Abstract strategy that resolves GaugeTokens from context + mode. Engine files must never import style files — they only consume GaugeTokens.
Constructors
- GaugeStyle()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
override(
GaugeTokensOverride overrides) → GaugeStyle - Wraps this style with a partial GaugeTokensOverride.
-
resolve(
BuildContext context, GaugeMode mode) → GaugeTokens -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited