TemperatureScale enum
Temperature scale selector.
- Inheritance
- Available extensions
Values
- celsius → const TemperatureScale
- fahrenheit → const TemperatureScale
- kelvin → const TemperatureScale
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
Available on TemperatureScale, provided by the TemperatureScaleConvert extension
no setter
Methods
-
convert(
double celsius) → double -
Available on TemperatureScale, provided by the TemperatureScaleConvert extension
Convertcelsius(internal storage) to this scale's display value. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TemperatureScale> - A constant List of the values in this enum, in order of their declaration.