FuelStatCard class
Pre-styled fuel-level card — pill-shaped bar gauge, percentage, turning lowColor below lowThreshold.
FuelStatCard(controller: fuelCtrl)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FuelStatCard
Constructors
- FuelStatCard({Key? key, required GaugeController controller, String label = 'FUEL', Color accentColor = const Color(0xFFFB7185), Color lowColor = const Color(0xFFEF4444), double lowThreshold = 15, bool showGlow = true, DashboardCardStyle cardStyle = const DashboardCardStyle(), GaugeMode? mode})
-
const
Properties
- accentColor → Color
-
Accent colour above lowThreshold.
final
- cardStyle → DashboardCardStyle
-
Card chrome (background, border, corner radius, text styles).
final
- controller → GaugeController
-
Drives the bar fill (0–100 %).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
Small uppercase card label.
final
- lowColor → Color
-
Accent colour at or below lowThreshold.
final
- lowThreshold → double
-
Fuel percentage below which lowColor is used.
final
- mode → GaugeMode?
-
Ambient or instrument rendering mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGlow → bool
-
Whether to cast an accent-tinted glow behind the card.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited